<?php
/**
 * Plugin Name: Gou Manage My Account Menu - User Roles
 * Plugin URI: https://areedit.com/
 * Description: Extension for WooCommerce to manage my account menus. Functionality to add/update/rename, show/hide and change the layout of menus, set Multi-Level Dropdown menus, and you can also set the menus according to user roles on my account page.
 * Author: Aslam Khan Gouran
 * Text Domain: gwat-woocommerce-account-tabs
 * Version: 1.0.1.3
 * WC requires at least: 4.5
 * Tested up to: 6.0.3
 * Author URI: 
 *
 */

/**
 * Required functions
*/
 
global $gwat_woo_account_tabs;

class Gwat_Woocommerce_Account_tabs {
	
	protected $gwat_is_enable;
	protected $custom_endpoints;
	
	public function __construct() {
		
		add_filter( 'woocommerce_settings_tabs_array', array( $this, 'gwat_woocommerce_account_tabs_setting' ), 100 );
		add_action( 'woocommerce_settings_tabs_gwats', array( $this, 'gwat_config_page' ) );
		add_action('admin_enqueue_scripts', array( $this, 'gwat_backend_scripts' ) );
		add_action( 'woocommerce_update_options_gwats', array( $this, 'gwat_save_settings' ) );
		add_action( 'gwat_admin_setting_pages', array( $this, 'gwat_admin_setting_pages'), 10, 2  );
		add_filter( 'plugin_action_links', array( $this, 'gwat_action_link' ), 10, 2 );
		add_action('wp', array( $this, 'gwat_get_all_endpoints_on_my_account_page'));
		
		//front-end actions...
		$this->gwat_is_enable = $this->gwat_is_enable();
		
		if( $this->gwat_is_enable == 'yes' ){
			
			add_action( 'init', array( $this, 'gwat_set_endpoints_rewrite' ) );
			add_filter( 'wc_get_template', array( $this, 'gwat_wc_get_template' ), 100, 5 );
			add_action('wp_enqueue_scripts', array( $this, 'gwat_frontend_scripts' ), 100 );
			add_action( 'woocommerce_account_content', array( $this, 'gwat_woocommerce_account_content' ), 10 );
			
		}
		
		add_action('wp_ajax_gwat_set_endpoints', array( $this, 'gwat_set_endpoints' ) );
		add_action('wp_ajax_nopriv_gwat_set_endpoints', array( $this, 'gwat_set_endpoints' ) );
		
		add_action('wp_ajax_gwat_set_menu_orders', array( $this, 'gwat_set_menu_orders' ) );
		add_action('wp_ajax_nopriv_gwat_set_menu_orders', array( $this, 'gwat_set_menu_orders' ) );
		
		add_action('wp_ajax_gwat_delete_endpoints', array( $this, 'gwat_delete_endpoints' ) );
		add_action('wp_ajax_nopriv_gwat_delete_endpoints', array( $this, 'gwat_delete_endpoints' ) );
		
		/* ------- NEED HELP SCRIPT ------- */
		add_action('admin_footer', array( $this, 'gwat_need_help_popup' ));
		add_action('wp_ajax_gwat_need_help_request_submit', array( $this, 'gwat_need_help_request_submit' ) );
		add_action('wp_ajax_nopriv_gwat_need_help_request_submit', array( $this, 'gwat_need_help_request_submit' ) );
		
	}
	
	public function gwat_is_enable(){
		
		$settings = $this->gwat_get_settings();
		return isset( $settings['config']['enable'] ) ? $settings['config']['enable'] : 'no';
		
	
	}
	
	public function gwat_woocommerce_account_tabs_setting( $tabs ) {
		
		$tabs['gwats'] = __( 'Account Tabs', 'gwat-woocommerce-account-tabs' );
		return $tabs;
		
	}
	
	public function gwat_config_page() {
		
		$menu_items = wc_get_account_menu_items();
		
		if( !empty( $menu_items ) && !get_option( 'gwats_config_page_settings' ) ){
		
			global $wpdb;
			
			$table_name = $wpdb->prefix.'manage_wctabs';
			
			$wpdb->query("CREATE TABLE `".$table_name."` (
				  `id` int(11) NOT NULL,
				  `parent_id` int(11) NOT NULL,
				  `menu_title` varchar(200) NOT NULL,
				  `slug` varchar(200) NOT NULL,
				  `old_slug` varchar(200) NOT NULL,
				  `is_default` enum('t','f') NOT NULL DEFAULT 'f',
				  `is_active` enum('t','f') NOT NULL DEFAULT 'f',
				  `menu_order` int(11) NOT NULL,
				  `menu_type` enum('default','link','page') NOT NULL DEFAULT 'default',
				  `custom_link` varchar(500) NOT NULL,
				  `page_id` int(11) NOT NULL,
				  `user_roles` TEXT NOT NULL,
				  `wp_action` varchar(500) NOT NULL
				) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4;");
			
			$wpdb->query("ALTER TABLE `".$table_name."`
				ADD PRIMARY KEY (`id`);");
			
			$wpdb->query("ALTER TABLE `".$table_name."`
				MODIFY `id` int(11) NOT NULL AUTO_INCREMENT, AUTO_INCREMENT=1;");
			
			$this->gwat_reset_account_menus();
			
			update_option( 'gwats_config_page_settings', 1 );
			//echo "<pre>"; print_r($menu_items); echo "</pre>";
		
		}
		
		$this->gwat_include_admin_settings();
		
	}
	
	public function gwat_get_all_endpoints_on_my_account_page(){
	
		if( function_exists('is_account_page') && is_account_page() && isset( $_REQUEST['synchronize'] ) && $_REQUEST['synchronize'] == 'endpoints' ){
			
			global $wpdb;
			
			if( isset( $_REQUEST['reset'] ) && $_REQUEST['reset'] == 'yes' ){
				
				$wpdb->query($wpdb->prepare("TRUNCATE ".$wpdb->prefix."manage_wctabs"), array());
			
			}
			
			$this->gwat_reset_account_menus();
			
			wp_redirect(admin_url( 'admin.php?page=wc-settings&tab=gwats&section=menus' ));
			
			exit;
		
		};
	
	}
	
	public function gwat_reset_account_menus(){
		
		global $wpdb;
		
		$menu_items = wc_get_account_menu_items();
		
		foreach( $menu_items as $key => $val ){
		
			$wp_action = $this->gwat_get_wp_action($key);
			
			$menuorder = $wpdb->get_var( $wpdb->prepare( "SELECT MAX(menu_order)+%d FROM ".$wpdb->prefix."manage_wctabs", array(1) ) );
			
			$is_find = $wpdb->get_row( $wpdb->prepare( "SELECT * FROM ".$wpdb->prefix."manage_wctabs WHERE slug=%s", array($key) ) );
			
			$is_wp_action = $wpdb->get_row( $wpdb->prepare( "SELECT * FROM ".$wpdb->prefix."manage_wctabs WHERE wp_action != '' AND wp_action=%s", array($wp_action) ) );
			
			if( !$is_find && !$is_wp_action ){
			
				$wpdb->query(
					
					$wpdb->prepare(
					
						"INSERT ".$wpdb->prefix."manage_wctabs SET
						menu_title = %s,
						slug = %s,
						old_slug = %s,
						is_default = %s,
						is_active = %s,
						wp_action = %s,
						menu_order = %d",
						
						array( $val, $key, $key, 't', 't', $wp_action, $menuorder)
					
					)
				
				);
			
			}
		
		}
		
		// RESET WOOCOMMERCE ENDPOINT ACTIONS...
		$get_results = $wpdb->get_results( $wpdb->prepare( "SELECT * FROM ".$wpdb->prefix."manage_wctabs WHERE wp_action != '' ", array() ) );
		
		if( !empty( $get_results ) ){
			
			foreach( $get_results as $data ){
				
				$wp_action = $data->wp_action;
				$slug = $data->slug;
				$new_slug = get_option($wp_action, true);
				
				$wpdb->query( $wpdb->prepare( "UPDATE ".$wpdb->prefix."manage_wctabs SET slug=%s, old_slug=%s WHERE id=%d", array( $new_slug, $new_slug, $data->id ) ) );
				
				$wpdb->query( $wpdb->prepare( "UPDATE ".$wpdb->prefix."manage_wctabs SET slug=%s WHERE slug=%s", array( $new_slug, $slug ) ) );
			
			}
		
		}
	
	}
	
	public function gwat_get_wp_action($key){
		
		global $wpdb;
		
		if( trim( $key ) != '' ){
			
			$is_result = $wpdb->get_row(
			
				$wpdb->prepare(
				
					"SELECT option_name FROM `".$wpdb->prefix."options` WHERE ( ( `option_name` LIKE %s AND `option_name` LIKE %s AND `option_value` LIKE %s ) || (`option_name` LIKE %s) )",
					
					array( '%woocommerce_myaccount_%', '%_endpoint%', $key, 'woocommerce_myaccount_'.$key.'_endpoint' )
				
				)
			
			);
			
			if( !empty( $is_result ) ){
				
				return $is_result->option_name;
			
			}
			
		}
		
		return false;
	
	}
	
	public function gwat_include_admin_settings(){
		
		include('admin/gou-woo-account-tab-settings.php');
		
	}
	
	public function gwat_backend_scripts(){
		
		$current_page = get_current_screen()->base;
		
		if( $current_page == 'woocommerce_page_wc-settings' && ( isset( $_REQUEST['tab'] ) && $_REQUEST['tab'] == 'gwats' ) ){
			
			wp_enqueue_style( 'wp-color-picker' ); 
			
			wp_enqueue_script( 'wp-color-picker' );
			
			$translation_array = array(
				'gwat_ajax_url' => admin_url( 'admin-ajax.php' ),
				'gwat_delete_confirmation' => __( 'Are you want to remove this menu.', 'gwat-woocommerce-account-tabs' )
			);
			
			wp_enqueue_script('jquery-gwat-nestedSortable-js', plugins_url('admin/assets/js/jquery.gwat.nestedsortable.js', __FILE__), array('jquery'), '1.0.1.3', true);
		
			wp_register_script('jquery-gwat-custom-js', plugins_url('admin/assets/js/jquery.gwat.custom.js', __FILE__), array('jquery'), '1.0.1.3', true);
			
			wp_localize_script( 'jquery-gwat-custom-js', 'gwat_localize_script', $translation_array );
			
			wp_enqueue_script( 'jquery-gwat-custom-js' );
			
			wp_enqueue_style( 'gwat-style-backend', plugins_url('admin/assets/css/style-backend.css', __FILE__), array(), '1.0.1.3', false );
			
			if( isset( $_REQUEST['section'] ) && $_REQUEST['section'] == 'layout' ){
			
				wp_enqueue_style( 'gwat-style-menu-preview', plugins_url('admin/assets/css/style-menu-preview.css', __FILE__), array(), '1.0.1.3', false );
				$gwat_custom_css = $this->gwat_style_menu_preview();
				wp_add_inline_style( 'gwat-style-menu-preview', $gwat_custom_css );
				
			}
			
		}
		
	}
	
	public function gwat_frontend_scripts(){
		
		if(  function_exists('is_account_page') && is_account_page() ){
			
			wp_enqueue_style( 'gwat-style-frontend', plugins_url('assets/css/style-frontend.css', __FILE__), array(), '1.0.1.3', false );
			$gwat_custom_css = $this->gwat_style_frontend();
			wp_add_inline_style( 'gwat-style-frontend', $gwat_custom_css );
			
			wp_enqueue_script('jquery-gwat-frontend-js', plugins_url('assets/js/jquery.gwat.frontend.js', __FILE__), array('jquery'), '1.0.1.3', true);
			
		}
	
	}
	
	public function gwat_style_menu_preview(){
		
		ob_start();
		
			include('admin/assets/css/style-menu-preview.php');
		
		return ob_get_clean();
	
	}
	
	public function gwat_style_frontend(){
		
		ob_start();
		
			include('assets/css/style-frontend.php');
		
		return ob_get_clean();
	
	}
	
	public function gwat_save_settings() {
		
		
		if ( ! wp_verify_nonce( $_REQUEST['_wpnonce'], 'woocommerce-settings' ) ) {
			die( __( 'Action failed. Please refresh the page and retry.', 'gwat-woocommerce-account-tabs' ) );
		}
		
		//general settings save...
		if( isset( $_POST['woocommerce_gwat_config_settings'] ) ){
			update_option( 'woocommerce_gwat_config', array_map( 'sanitize_text_field', (array)$_POST['woocommerce_gwat_config'] ) );
		}
		
		//layout settings save...	
		if( isset( $_POST['woocommerce_gwat_layout_settings'] ) ){
			update_option( 'woocommerce_gwat_layout', array_map( 'sanitize_text_field', (array)$_POST['woocommerce_gwat_layout'] ) );
		}
			
	}
	
	public function gwat_get_settings(){
		
		$config = get_option( 'woocommerce_gwat_config', true );
		$layout = get_option( 'woocommerce_gwat_layout', true );
		
		$config_settings = array(
			
			'config' => $config,
			'layout' => $layout
			
		);
		
		return apply_filters('gwat_config_settings', $config_settings);
		
	}
	
	public function gwat_admin_setting_pages( $section, $tab ){
		
		if( $section == '' ){
			
			include('admin/gou-woo-general-settings.php');
			
		}
		
		if( $section == 'layout' ){
		
			include('admin/gou-woo-layout-settings.php');
			
		}
		
		if( $section == 'menus' ){
		
			include('admin/gou-woo-menus-settings.php');
			
		}
	
	}
	
	public function gwat_action_link( $actions, $plugin_file ) {
		
		if ( $plugin_file == 'gou-wc-account-tabs/gou-woo-account-tabs.php' && function_exists('is_account_page') ) {
			
			$settings = array( 'settings' => '<a href="' . admin_url( 'admin.php?page=wc-settings&tab=gwats' ) . '">' . __( 'Settings', 'gwat-woocommerce-account-tabs' ) . '</a>' );

			$actions = array_merge( $settings, $actions );
		}
		
		return $actions;
	}
	
	public function gwat_woocommerce_account_endpoint($value){
		
		global $wp;
		
		$html = '<div class="gou_woocommerce_endpoint_container">';
		
			//echo "<pre>"; print_r($wp->query_vars); echo "</pre>";
			//echo "<pre>"; print_r($this->custom_endpoints); echo "</pre>";
			
			$endpoint_slug =  '' ;
			
			if( is_array( $this->custom_endpoints ) && !empty( $this->custom_endpoints ) ){
				
				foreach( $this->custom_endpoints as $endpoint ){
					
					if( array_key_exists( $endpoint, $wp->query_vars) ){
						
						$endpoint_slug =  $endpoint;
					
					}
				
				}
				
			}
			
			// in the case of dashboard...
			if( $endpoint_slug == '' && !empty( $this->custom_endpoints ) && in_array( 'dashboard', $this->custom_endpoints) && !array_key_exists( 'dashboard', $wp->query_vars) ){
				
				$endpoint_slug =  'dashboard';
			
			}
			
			$wat_page_id = isset( $wp->query_vars['gwat-endpoint-'.$endpoint_slug] ) ? $wp->query_vars['gwat-endpoint-'.$endpoint_slug] : '' ;
			
			if( $wat_page_id > 0 ){
				
				$contentElementor = '';
				
				if (class_exists("\\Elementor\\Plugin")) {
					$pluginElementor = \Elementor\Plugin::instance();
					$contentElementor = $pluginElementor->frontend->get_builder_content($wat_page_id);
				}
				
				if( trim( $contentElementor ) == '' ){
					
					$content_post = get_post($wat_page_id);
					$content = $content_post->post_content;
					$content = apply_filters('the_content', $content);
					$contentElementor = str_replace(']]>', ']]&gt;', $content);
					
				}
				
				$html .= $contentElementor;
				
			}
			
		$html .= '</div>';
		
		echo wp_specialchars_decode( $html );

	}
	
	public function gwat_set_endpoints_rewrite() {
		
		global $wpdb;
		
		$get_results = $wpdb->get_results( $wpdb->prepare( "SELECT * FROM ".$wpdb->prefix."manage_wctabs WHERE menu_type != %s AND slug != old_slug ORDER BY menu_order ASC", array( 'link' ) ) );
		
		if( !empty( $get_results ) ){
			
			foreach( $get_results as $data ){
				
				add_rewrite_endpoint( $data->slug, EP_ROOT | EP_PAGES );
			
			}
			
			if( !get_option( 'gwats_add_update_endpoints' ) ) {
				// Flush rules after endpoint add/update
				flush_rewrite_rules();
				update_option( 'gwats_add_update_endpoints', 1 );
			}
			
		}
		
	}
	
	public function gwat_wc_get_template( $template, $template_name, $args, $template_path, $default_path ){

		if( $template_name == 'myaccount/navigation.php' ){
			
			if( locate_template( array( 'gou-woo/navigation.php' ) ) ){
				$template = locate_template( array( 'gou-woo/navigation.php' ) );
			}else{
				$template = WP_PLUGIN_DIR .'/'. plugin_basename( dirname(__FILE__) ) .'/templates/navigation.php';
			}
			
			$template = apply_filters( 'gou_woo_account_template', $template, $template_name, $args, $template_path, $default_path );
			
		}
		
		if( $template_name == 'myaccount/my-account.php' ){
			
			if( locate_template( array( 'gou-woo/my-account.php' ) ) ){
				$template = locate_template( array( 'gou-woo/my-account.php' ) );
			}else{
				$template = WP_PLUGIN_DIR .'/'. plugin_basename( dirname(__FILE__) ) .'/templates/my-account.php';
			}
			
			$template = apply_filters( 'gou_woo_account_template', $template, $template_name, $args, $template_path, $default_path );
			
		}
		
		return $template;
	}
	
	public function gwat_show_endpoints_navigation( $id = 0, $current_tab = 0, $level = 0 ){
		
		global $wpdb, $wp;
		
		$user = wp_get_current_user();
		
		$role_condition_arr = array();
		
		if( !empty( $user->roles ) ){
			
			foreach( $user->roles as $role ){
				
				$role_condition_arr[] = $wpdb->prepare( "FIND_IN_SET(%s, user_roles)", array($role) );
				
			}
		
		}
		
		$role_condition_str = " AND ( ( user_roles = '' ) OR ( ".implode( ' OR ', $role_condition_arr )." ) ) ";
		
		$get_results = $wpdb->get_results( $wpdb->prepare( "SELECT * FROM ".$wpdb->prefix."manage_wctabs WHERE parent_id=%d AND is_active=%s ".$role_condition_str." ORDER BY menu_order ASC", array( $id, 't' ) ) );
		
		$html = '';
		
		if( !empty( $get_results ) ){
			
			if( $id > 0 ){
				$html .= '<ul class="dropdown-menu-sub level-'.$level.'">';
				$level++;
			}
			
				foreach( $get_results as $data ){
					
					$menu_slug = !empty( $data->old_slug ) ? $data->old_slug : $data->slug;
					
					if( $data->menu_type == 'link' ){
						$endpoint_url = esc_url( $data->custom_link );
					}else{
						$endpoint_url = esc_url( wc_get_account_endpoint_url( $menu_slug ) );
					}
					
					$get_total = 0;
					$parent_class = '';
					if( $data->id > 0 ){
					
						$get_total = $wpdb->get_var( $wpdb->prepare("SELECT COUNT(id) FROM ".$wpdb->prefix."manage_wctabs WHERE parent_id=%d AND is_active=%s ORDER BY menu_order ASC", array($data->id, 't' )) );
						if( $get_total > 0 ){
							$parent_class = 'parent-menu';
							$endpoint_url = 'javascript:void(0);';
							
						}
						
					}
					
					if( $parent_class == '' && $data->menu_type == 'page' ){
						
						$this->custom_endpoints[] = $data->slug;
						$wp->query_vars['gwat-endpoint-'.$data->slug] = $data->page_id;
						
						remove_all_actions( 'woocommerce_account_'.$data->slug.'_endpoint' );
						
						if( $data->slug == 'dashboard' ){
						
							remove_all_actions( 'woocommerce_account_page_endpoint' );
							remove_all_actions( 'woocommerce_account_gwat-endpoint-dashboard_endpoint' );
							
							add_action( 'woocommerce_account_page_endpoint', array( $this, 'gwat_woocommerce_account_endpoint') );
							add_action( 'woocommerce_account_gwat-endpoint-dashboard_endpoint', array( $this, 'gwat_woocommerce_account_endpoint') );
							
						}else{
						
							add_action( 'woocommerce_account_'.$data->slug.'_endpoint', array( $this, 'gwat_woocommerce_account_endpoint') );
						
						}
						
					}
					
					$mobile_arrow = '';
					if( $level > 0 ){
						
						for($i=0; $i < $level; $i++ ){
							
							$mobile_arrow .= '<font class="mobile_menu_arrow">&#8594;</font>';
							
						}
						
						$mobile_arrow = apply_filters('gwat_mobile_menu_arrow', $mobile_arrow, $level);
						
					}
						
					
					$html .= '<li class="'. wc_get_account_menu_item_classes( $menu_slug ).' '.$parent_class.' ">';
					
					$html .= '<a href="'.$endpoint_url.'" class="menuDiv manage-menu-container">'.$mobile_arrow.__( $data->menu_title, 'gwat-woocommerce-account-tabs' ).'</a>';
					
					$html .= $this->gwat_show_endpoints_navigation($data->id, '', $level);
					
					$html .= '</li>';
					
				}
			
			if( $id > 0 ){
				$html .= '</ul>';
			}
			
		
		}
		
		return $html;
		
	}
	
	public function gwat_add_update_menu_form( $data = array() ){
	
		$menu_counter = isset( $data->id ) ? $data->id : 0;
		
		$wat_user_roles = !empty( $data->user_roles ) ? explode(',', $data->user_roles) : array();
		
		$html = '<table class="form-table">
					
			<tbody>
			
			<tr valign="top">
				<th scope="row" class="titledesc">
					<label for="wat_menu_label_'.esc_attr( $menu_counter ).'">'.__('Menu Latel', 'gwat-woocommerce-account-tabs' ).' </label>
				</th>
				<td class="forminp forminp-text">
					<input name="wat_menu_label" id="wat_menu_label_'.esc_attr( $menu_counter ).'" type="text" style="" value="'.( isset($data->menu_title) ? esc_attr( stripslashes($data->menu_title) ) : '' ).'" class="" placeholder=""> 
				</td>
			</tr>
			
			<tr valign="top">
				<th scope="row" class="titledesc">
					<label for="wat_menu_slug_'.esc_attr( $menu_counter ).'">'.__('Menu Slug', 'gwat-woocommerce-account-tabs' ).' </label>
				</th>
				<td class="forminp forminp-text">
					<input name="wat_menu_slug" id="wat_menu_slug_'.esc_attr( $menu_counter ).'" type="text" '.( ( isset( $data->is_default ) && esc_attr( $data->is_default ) == 't' ) ? 'readonly="readonly"' : '' ).' value="'.( isset($data->slug) ? esc_attr( $data->slug ) : '' ).'" class="" placeholder=""> 									
					<em class="gou-slug-error"></em>
					<p class="gou-description">Make sure, should not be duplicate slug for any menu items on my account page.</p>
				</td>
			</tr>
			
			<tr valign="top" class="show_options_if_checked">
				<th scope="row" class="titledesc">
					<label for="wat_menu_content_type_'.esc_attr( $menu_counter ).'">'.__('Menu Content', 'gwat-woocommerce-account-tabs' ).' </label>
				</th>
				<td class="forminp">
					
				<select name="wat_menu_content_type" id="wat_menu_content_type_'.esc_attr( $menu_counter ).'" class="wc-enhanced-select enhanced" data-placeholder="Select type�" style="min-width:300px;">
					<option value="default" '.( (isset($data->menu_type) && esc_attr( $data->menu_type ) == 'default' ) ? 'selected="selected"' : '' ).'>'.__('Default', 'gwat-woocommerce-account-tabs' ).'</option>
					<option value="link" '.( (isset($data->menu_type) && esc_attr( $data->menu_type ) == 'link' ) ? 'selected="selected"' : '' ).'>'.__('Custom Link', 'gwat-woocommerce-account-tabs' ).'</option>
					<option value="page" '.( (isset($data->menu_type) && esc_attr( $data->menu_type ) == 'page' ) ? 'selected="selected"' : '' ).'>'.__('Page', 'gwat-woocommerce-account-tabs' ).'</option>
				</select>
		
				</td>
			</tr>
			
			<tr valign="top" class="wat_menu_content_custom link" '.( (isset($data->menu_type) && esc_attr( $data->menu_type ) == 'link' ) ? '' : 'style="display:none;"' ).'>
				<th scope="row" class="titledesc">
					<label for="wat_custom_link_'.esc_attr( $menu_counter ).'">'.__('Custom Link', 'gwat-woocommerce-account-tabs' ).' </label>
				</th>
				<td class="forminp forminp-text">
					<input name="wat_custom_link" id="wat_custom_link_'.esc_attr( $menu_counter ).'" type="text" style="" value="'.( isset($data->custom_link) ? esc_attr( stripslashes($data->custom_link) ) : '' ).'" class="" placeholder=""> 									
				</td>
			</tr>
			
			<tr valign="top" class="wat_menu_content_custom page" '.( (isset($data->menu_type) && esc_attr( $data->menu_type ) == 'page' ) ? '' : 'style="display:none;"' ).'>
				<th scope="row" class="titledesc">
					<label for="wat_custom_page_'.esc_attr( $menu_counter ).'">'.__('Select Page', 'gwat-woocommerce-account-tabs' ).' </label>
				</th>
				<td class="forminp">';
				
				
				
				$args = array(
					
					'echo' => 0,
					'name' => 'wat_custom_page',
					'selected' => ( (isset($data->page_id) && $data->page_id != '' ) ? esc_attr( $data->page_id ) : '' ),
					'class'                 => 'wc-enhanced-select enhanced', // string
					'id'                 => 'wat_custom_page_'.esc_attr( $menu_counter ), // string
					'show_option_none'      => __('Select Page', 'gwat-woocommerce-account-tabs' ), // string
					'show_option_no_change' => null, // string
					'option_none_value'     => null, // string
				
				);
				
			$html .= wp_dropdown_pages( $args );
				
			   
				
			$html .= '</td>
			</tr>
			
			<tr valign="top" class="show_options_if_checked">
				<th scope="row" class="titledesc">
				<label for="wat_is_active_'.esc_attr( $menu_counter ).'">'.__('Is Active', 'gwat-woocommerce-account-tabs' ).' </label>
				</th>
				<td class="forminp forminp-checkbox">
					<input name="wat_is_active" id="wat_is_active_'.esc_attr( $menu_counter ).'" type="checkbox" class="" value="1" '.( (isset($data->is_active) && esc_attr( $data->is_active ) == 't' ) ? 'checked="checked"' : '' ).'> '.__('Checked this to enable menu.', 'gwat-woocommerce-account-tabs' ).'
				</td>
			</tr>
			
			<tr valign="top" class="show_options_if_checked">
				<th scope="row" class="titledesc">
				<label for="wat_only_for_roles_'.esc_attr( $menu_counter ).'">'.__('Roles', 'gwat-woocommerce-account-tabs' ).' </label>
				</th>
				<td class="forminp forminp-checkbox">
					<select multiple="multiple" id="wat_only_for_roles_'.esc_attr( $menu_counter ).'" name="wat_user_roles[]" data-placeholder="'. __( 'Select Roles', 'gwat-woocommerce-account-tabs' ).'" class="gwat-chosen-select">
						'.$this->gwat_get_user_roles_options( array_map( 'trim', $wat_user_roles ) ).'
					</select>
					<p class="gou-description">Leave unselect, if you want to show this menu show for all user roles.</p>
				</td>
			</tr>
			
			
			</tbody>
			
		</table>
		
		<input type="hidden" name="id" value="'.( isset($data->id) ? esc_attr( $data->id ) : '' ).'" />';
		
		return $html;
	
	}
	
	public function gwat_set_endpoints(){
	
		global $wpdb;
		
		$submit_message = array();
		
		$wat_menu_label = isset( $_POST['wat_menu_label'] ) ? sanitize_text_field( trim( $_POST['wat_menu_label'] ) ) : '';
		$wat_menu_slug = isset( $_POST['wat_menu_slug'] ) ? sanitize_text_field( trim( $_POST['wat_menu_slug'] ) ) : '';
		$wat_menu_content_type = isset( $_POST['wat_menu_content_type'] ) ? sanitize_text_field( $_POST['wat_menu_content_type'] ) : '';
		$wat_custom_link = isset( $_POST['wat_custom_link'] ) ? sanitize_text_field( trim($_POST['wat_custom_link']) ) : '';
		$wat_custom_page = isset( $_POST['wat_custom_page'] ) ? sanitize_text_field( $_POST['wat_custom_page'] ) : '';
		$wat_is_active = isset( $_POST['wat_is_active'] ) ? sanitize_text_field( $_POST['wat_is_active'] ) : '';
		$user_roles = isset( $_POST['wat_user_roles'] ) ? array_map( 'sanitize_text_field', (array)$_POST['wat_user_roles'] ) : '';
		
		$user_roles_str = '';
		
		if( !empty( $user_roles ) ){
			$user_roles_str = implode( ",", $user_roles );
		}
		
		//echo "<pre>"; print_r($user_roles); echo "</pre>"; exit;
		
		$id = isset( $_POST['id'] ) ? (int)$_POST['id'] : '';
		
		if( $wat_is_active ){$wat_is_active = 't';}
		
		
		$html = '';
		
		if( $wat_menu_label != '' && $wat_menu_slug != '' ){
			
			if( $id > 0 ){
				
				$wpdb->query(
				
				$wpdb->prepare(
				
					"UPDATE ".$wpdb->prefix."manage_wctabs SET	
					menu_title = %s,
					slug = %s,
					is_active = %s,
					menu_type = %s,
					custom_link = %s,
					user_roles = %s,
					page_id = %d
					WHERE
					id=%d",
					
					array( $wat_menu_label, $wat_menu_slug, $wat_is_active, $wat_menu_content_type, $wat_custom_link, $user_roles_str, $wat_custom_page, $id )
				)
				
				
				);
				
				
				$roles_html = array();
				
				$all_user_roles = $this->gwat_get_user_roles();
				
				if( !empty( $user_roles ) ){
					
					foreach( $user_roles as $role ){
						
						if( array_key_exists( $role, $all_user_roles ) )
						$roles_html[] = $all_user_roles[$role];
					
					}
				
				}else{
					
					foreach( $all_user_roles as $role => $val ){
						
						$roles_html[] = $val;
					
					}
				
				}
				
				
				
				//echo "<pre>"; print_r($roles_html); echo "</pre>";
				
				$submit_message['type'] = 'edit';
				$submit_message['title'] = stripslashes( $wat_menu_label );
				$submit_message['roles_html'] = "[ ".implode( ', ', $roles_html )." ]";
				
				$html = '';
				
			}else{
				
				$menuorder = $wpdb->get_var( $wpdb->prepare( "SELECT MAX(menu_order)+%d FROM ".$wpdb->prefix."manage_wctabs", array(1) ) );
				
				$wpdb->query(
					
					$wpdb->prepare(
						"INSERT ".$wpdb->prefix."manage_wctabs SET
						menu_title = %s,
						slug = %s,
						is_default = 'f',
						is_active = %s,
						menu_order = %d,
						menu_type = %s,
						custom_link = %s,
						user_roles = %s,
						page_id = %d",
						
						array( $wat_menu_label, $wat_menu_slug, $wat_is_active, $menuorder, $wat_menu_content_type, $wat_custom_link, $user_roles_str, $wat_custom_page )
					)
					
				);
				
				$lastid = $wpdb->insert_id;
				
				$id = $lastid;
				
				$submit_message['type'] = 'add';
				
				ob_start();
				echo wp_specialchars_decode( $this->gwat_show_menu_html(0, $lastid) );
				$html = ob_get_clean();
				
			}
			
			$submit_message['code'] = 200;
			$submit_message['html'] = base64_encode($html);
			$submit_message['menu_item_id'] = 'menuItem_'.$id;
			$submit_message['success'] = __('Menu created successfully.', 'gwat-woocommerce-account-tabs' );
			
			// Flush rules enable after endpoint add/update
			if( get_option( 'gwats_add_update_endpoints' ) ) {
				delete_option( 'gwats_add_update_endpoints' );
			}
		
		}
		
		echo json_encode($submit_message);
		
		exit;
		
	}
	
	public function gwat_set_menu_orders(){
	
		global $wpdb;
		
		$serializedata = isset( $_POST['serializedata'] ) ? sanitize_textarea_field($_POST['serializedata']) : '';
		
		if( $serializedata != '' ){
			
			$unserialize_data = array();
			parse_str($serializedata, $unserialize_data);
			
			if( isset( $unserialize_data['menuItem'] ) && !empty( $unserialize_data['menuItem'] ) ){
				
				$i = 0;
				foreach( $unserialize_data['menuItem'] as $key => $val ){
					
					$val = ( $val == 'null' ) ? 0 : $val;
					
					$wpdb->query(
						
						$wpdb->prepare(
							
							"UPDATE ".$wpdb->prefix."manage_wctabs SET parent_id = %d, menu_order=%d WHERE id=%d", 
							array( $val, $i, $key)
						
						)
					
					);
					
					$i++;
					
				}
			
			}
		
		}
		
		exit;
		
	}
	
	public function gwat_delete_endpoints(){
	
		global $wpdb;
		
		$menu_id = isset( $_POST['menu_id'] ) ? (int)$_POST['menu_id'] : '';
		
		$submit_message = array();
		
		if( $menu_id > 0 ){
			
			$get_total = $wpdb->get_var( $wpdb->prepare( "SELECT COUNT(id) FROM ".$wpdb->prefix."manage_wctabs WHERE parent_id=%d", array( $menu_id ) ) );
			
			if( $get_total > 0 ){
				
				$submit_message['code'] = 401;
				$submit_message['message'] = __( 'Must be remove child items.', 'gwat-woocommerce-account-tabs' );
				 
			}else{
				
				$wpdb->query( $wpdb->prepare( "DELETE FROM ".$wpdb->prefix."manage_wctabs WHERE id = %d", array($menu_id) ) );
				
				$submit_message['code'] = 200;
				$submit_message['message'] = __( 'Menu removed successfully.', 'gwat-woocommerce-account-tabs' );
				
			}
		
		}
		
		echo json_encode($submit_message);
		
		exit;
		
	}
	
	public function gwat_show_menu_html( $id = 0, $current_tab = 0 ){
	
		global $wpdb;
		
		if( $current_tab > 0 ){
			
			$get_results = $wpdb->get_results( $wpdb->prepare( "SELECT * FROM ".$wpdb->prefix."manage_wctabs WHERE id=%d ORDER BY menu_order ASC", array($current_tab) ) );
			
		}else{
		
			$get_results = $wpdb->get_results( $wpdb->prepare( "SELECT * FROM ".$wpdb->prefix."manage_wctabs WHERE parent_id=%d ORDER BY menu_order ASC", array($id) ) );
		
		}
		
		$html = '';
		
		if( !empty( $get_results ) ){
			
			if( $id > 0 ){
				$html .= '<ol>';
			}
			
				foreach( $get_results as $data ){
					
					$roles_html = array();
				
					$all_user_roles = $this->gwat_get_user_roles();
					
					$user_roles = !empty( $data->user_roles ) ? explode(',', $data->user_roles) : array();
					
					if( !empty( $user_roles ) ){
						
						foreach( $user_roles as $role ){
							
							if( array_key_exists( $role, $all_user_roles ) )
							$roles_html[] = $all_user_roles[$role];
						
						}
					
					}else{
						
						foreach( $all_user_roles as $role => $val ){
							
							$roles_html[] = $val;
						
						}
					
					}
					
					$roles_html = "[ ".implode( ', ', $roles_html )." ]";
					
					$html .= '<li style="display: list-item;" class="mjs-nestedSortable-branch mjs-nestedSortable-expanded" id="menuItem_'.esc_attr( $data->id ).'">';
					
					$html .= '<div class="menuDiv manage-menu-container">
				   <span title="'.__( 'Click to show/hide children', 'gwat-woocommerce-account-tabs' ).'" class="disclose ui-icon ui-icon-minusthick">
					<span></span>
				   </span>
				   <span title="'.__( 'Click to show/hide item settings', 'gwat-woocommerce-account-tabs' ).'" data-id="'.esc_attr( $data->id ).'" class="expandEditor ui-icon ui-icon-triangle-1-n">
					<span></span>
				   </span>
				   <span>
				   <span data-id="'.$data->id.'" class="itemTitle"><font class="title">'.esc_attr( stripslashes( $data->menu_title ) ).'</font>&nbsp;::&nbsp;<font class="roles"><em>'.esc_attr( $roles_html ).'</em></font></span>
				   <!--<span title="Click to delete item." data-id="'.esc_attr( $data->id ).'" class="deleteMenu ui-icon ui-icon-closethick">
				   <span></span>
				   </span>-->
				   </span>
				   <div id="menuEdit'.esc_attr( $data->id ).'" class="menuEdit hidden">
					   <div class="menu-form wat-form-to-update-menu">';
					   
					   $html .= $this->gwat_add_update_menu_form( $data );
						
						$html .= '<p class="submit">
							<button name="save" class="button-primary save-to-create-menu" type="button" value="'.__( 'Save changes', 'gwat-woocommerce-account-tabs' ).'">'.__( 'Save changes', 'gwat-woocommerce-account-tabs' ).'</button>';
							
							if( $data->is_default == 'f' ){
								$html .= '<button name="delete-menu" title="'.__( 'Click to delete menu.', 'gwat-woocommerce-account-tabs' ).'" delete-id="'.esc_attr( $data->id ).'" class="button-primary delete-to-existing-menu" type="button" value="'.__( 'Delete Manu', 'gwat-woocommerce-account-tabs' ).'">'.__( 'Delete', 'gwat-woocommerce-account-tabs' ).'</button>';
							}
							
						$html .= '</p>
							
					   </div>
				   </div>
			   </div>';
					
					$html .= $this->gwat_show_menu_html($data->id);
					
					$html .= '</li>';
					
				}
			
			if( $id > 0 ){
				$html .= '</ol>';
			}
			
		
		}
		
		return $html;
		
	}
	
	public function gwat_woocommerce_account_content() {
	
		global $wp;

		if ( ! empty( $wp->query_vars ) ) {
			foreach ( $wp->query_vars as $key => $value ) {
				// Ignore pagename param.
				if ( 'pagename' === $key ) {
					continue;
				}
				
				if ( has_action( 'woocommerce_account_' . $key . '_endpoint' ) ) {
					do_action( 'woocommerce_account_' . $key . '_endpoint', $value );
					return;
				}
			}
		}

		// No endpoint found? Default to dashboard.
		wc_get_template(
			'myaccount/dashboard.php',
			array(
				'current_user' => get_user_by( 'id', get_current_user_id() ),
			)
		);
	}
	
	public function gwat_get_user_roles(){
	
		global $wp_roles;
		
		$roles_arr = array();
		
		foreach( $wp_roles->roles as $key => $val ){
			
			$roles_arr[$key] = $val['name'];
			
		}
		
		return $roles_arr;
	
	}
	
	public function gwat_get_user_roles_options( $values = array() ){
		
		$user_roles = $this->gwat_get_user_roles();
		
		ob_start();
		
		$html = '';
		
		foreach( $user_roles as $key => $val ){
			
			$selected = '';
			if( !empty( $values ) && in_array( $key, $values ) )
				$selected = 'selected="selected"';
			
			$html .= '<option '.$selected.' value="'.esc_attr( $key ).'">'.esc_attr( $val ).'</option>';
		
		}
		
		echo wp_specialchars_decode( $html );
		
		return ob_get_clean();
	
	}
	
	public function gwat_need_help_popup(){
		
		$current_page = get_current_screen()->base;
		
		if( $current_page == 'woocommerce_page_wc-settings' && ( isset( $_REQUEST['tab'] ) && $_REQUEST['tab'] == 'gwats' ) ){
			
			include('admin/gou-woo-need-help-popup.php');
			
		}
	
	}
	
	public function gwat_need_help_request_submit(){
	
		global $wpdb;
		
		$submit_message = array();
		
		$full_name = isset( $_POST['gwat_need_help_full_name'] ) ? sanitize_text_field( trim( $_POST['gwat_need_help_full_name'] ) ) : '';
		$email = isset( $_POST['gwat_need_help_email'] ) ? sanitize_text_field( trim( $_POST['gwat_need_help_email'] ) ) : '';
		$message = isset( $_POST['gwat_need_help_message'] ) ? sanitize_textarea_field( $_POST['gwat_need_help_message'] ) : '';
		
		$to = 'aslamkhangouran@gmail.com';
		
		$headers = "MIME-Version: 1.0\r\n";
		$headers .= "Content-Type: text/html; charset=ISO-8859-1\r\n";
		$headers .= 'From: '.get_bloginfo('name').' <'.$email .'>';
		
		if( !function_exists('get_plugin_data') ){
			require_once( ABSPATH . 'wp-admin/includes/plugin.php' );
		}
		
		$plugin_data = get_plugin_data( __FILE__ );
		$plugin_name = $plugin_data['Name'];
		
		$subject = sprintf( esc_attr('Need Help ( %s )', 'gwat-woocommerce-account-tabs' ), $plugin_name );
		
		$message .= "\r\n\r\n";
		$message .= sprintf( esc_attr('Name : %s', 'gwat-woocommerce-account-tabs' ), $full_name )."\r\n";
		$message .= sprintf( esc_attr('Email : %s', 'gwat-woocommerce-account-tabs' ), $email )."\r\n";
		$message .= sprintf( esc_attr('Website : %s', 'gwat-woocommerce-account-tabs' ), site_url() );
		
		wp_mail($to, wp_specialchars_decode($subject),  wp_specialchars_decode(nl2br($message)), $headers);
		
		$submit_message['code'] = 200;
		
		echo json_encode($submit_message);
		
		exit;
		
	}
	 
}


$gwat_woo_account_tabs = new Gwat_Woocommerce_Account_tabs();




